@@ -36,7 +36,6 @@
 #include "gtr-application.h"
 #include "gtr-dirs.h"
 #include "gtr-file-dialogs.h"
-//#include "gtr-notebook.h"
 #include "gtr-po.h"
 #include "gtr-tab.h"
 #include "gtr-utils.h"
@@ -255,6 +254,7 @@ static void
 save_dialog_response_cb (GObject *source, GAsyncResult *res, void *user_data)
 {
   g_autoptr (GError) error = NULL;
+  g_autoptr (GError) save_error = NULL;
   GtrPo *po;
   GtrTab *tab;
   GtkFileDialog *dialog = GTK_FILE_DIALOG (source);
@@ -267,9 +267,23 @@ save_dialog_response_cb (GObject *source, GAsyncResult *res, void *user_data)
   tab = gtr_window_get_active_tab (window);
   po = gtr_tab_get_po (tab);
 
-  // FIXME: handle errors here
-  file = gtk_file_dialog_save_finish (dialog, res, NULL);
-  if (!file) return;
+  file = gtk_file_dialog_save_finish (dialog, res, &save_error);
+  if (save_error)
+  {
+    if (g_error_matches (save_error, GTK_DIALOG_ERROR, GTK_DIALOG_ERROR_DISMISSED))
+      return;
+
+    AdwDialog *alert_dialog;
+
+    alert_dialog = adw_alert_dialog_new (_("Could not save file"), NULL);
+    adw_alert_dialog_add_response (ADW_ALERT_DIALOG (alert_dialog), "ok", _("OK"));
+    adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (alert_dialog), "ok");
+    adw_dialog_present (ADW_DIALOG (alert_dialog), GTK_WIDGET (window));
+
+    g_error ("Could not save file: %s", save_error->message);
+
+    return;
+  }
   filename = g_file_get_path (file);
   location = g_file_new_for_path (filename);
 
@@ -281,10 +295,10 @@ save_dialog_response_cb (GObject *source, GAsyncResult *res, void *user_data)
 
       if (error)
         {
-          AdwDialog *dialog = adw_alert_dialog_new (NULL, error->message);
-          adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok", _("OK"));
-          adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "ok");
-          adw_dialog_present (ADW_DIALOG (dialog), GTK_WIDGET (window));
+          AdwDialog *alert_dialog = adw_alert_dialog_new (NULL, error->message);
+          adw_alert_dialog_add_response (ADW_ALERT_DIALOG (alert_dialog), "ok", _("OK"));
+          adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (alert_dialog), "ok");
+          adw_dialog_present (ADW_DIALOG (alert_dialog), GTK_WIDGET (window));
           return;
         }
 
@@ -323,6 +337,10 @@ _upload_file_callback (GObject      *object,
       if (status_code == SOUP_STATUS_FORBIDDEN)
         {
           dialog = adw_alert_dialog_new (_("This file has already been uploaded"), NULL);
+          adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok",
+                                         _("OK"));
+          adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog),
+                                                 "ok");
           gtr_tab_enable_upload (active_tab, FALSE);
           goto end;
         }
@@ -357,7 +375,7 @@ end:
   user_data_free (ud);
 }
 
-void
+static void
 gtr_upload_file (GtkWidget *upload_dialog,
                  gpointer   user_data)
 {
