@@ -293,6 +293,15 @@ edit_header_activated (GSimpleAction *action,
   gtr_actions_edit_header (get_active_window (app));
 }
 
+static void
+fix_plurals_activated (GSimpleAction *action, GVariant *parameter,
+                       gpointer user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  gtr_actions_fix_plurals (get_active_window (app));
+  gtr_window_add_toast_msg (get_active_window (app), _("Fixed plurals"));
+}
+
 static void
 clear_msgstr_activated (GSimpleAction *action,
                         GVariant      *parameter,
@@ -479,13 +488,14 @@ static GActionEntry app_entries[]
         { "new-window", new_window_activated, NULL, NULL, NULL },
         { "preferences", preferences_activated, NULL, NULL, NULL },
         { "edit_header", edit_header_activated, NULL, NULL, NULL },
+        { "fix-plurals", fix_plurals_activated, NULL, NULL, NULL },
         { "clear_msgstr", clear_msgstr_activated, NULL, NULL, NULL },
         { "help", help_activated, NULL, NULL, NULL },
         { "about", about_activated, NULL, NULL, NULL },
         { "quit", quit_activated, NULL, NULL, NULL } };
 
 static void
-set_kb (GApplication *app, gchar *action, gchar *accel)
+set_kb (GApplication *app, const gchar *action, const gchar *accel)
 {
   const gchar *keys[] = {accel, NULL};
   gtk_application_set_accels_for_action (GTK_APPLICATION (app), action, keys);
@@ -621,7 +631,7 @@ gtr_application_class_init (GtrApplicationClass *klass)
 }
 
 GtrApplication *
-gtr_application_new ()
+gtr_application_new (void)
 {
   return GTR_APPLICATION (g_object_new (GTR_TYPE_APPLICATION,
                                         "application-id", PACKAGE_APPID,
