@@ -562,7 +562,7 @@ gtr_tab_show_message (GtrTab * tab, GtrMsg * msg)
       if (gtr_msg_is_fuzzy (msg))
         gtk_label_set_text (GTK_LABEL (priv->msgid_tags), _("fuzzy"));
       if (msg_error) {
-        gtk_label_set_text (GTK_LABEL (priv->msgid_tags), msg_error);
+        gtk_label_set_text (GTK_LABEL (priv->msgid_tags), g_strstrip (msg_error));
         g_free (msg_error);
       }
     }
@@ -689,7 +689,7 @@ update_status (GtrTab * tab, GtrMsg * msg, gpointer useless)
 
   msg_error = gtr_msg_check (msg);
   if (msg_error) {
-    gtk_label_set_text (GTK_LABEL (priv->msgid_tags), msg_error);
+    gtk_label_set_text (GTK_LABEL (priv->msgid_tags), g_strstrip (msg_error));
     g_free (msg_error);
   }
   else if (gtr_msg_is_fuzzy (msg))
@@ -1016,7 +1016,10 @@ void
 gtr_tab_enable_upload (GtrTab *tab, gboolean enable)
 {
   GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
-  gtk_widget_set_sensitive (priv->upload, enable);
+  GtkApplication *app = gtk_window_get_application (GTK_WINDOW (priv->window));
+  GAction *action
+      = g_action_map_lookup_action (G_ACTION_MAP (app), "upload_file");
+  g_simple_action_set_enabled (G_SIMPLE_ACTION (action), enable);
 }
 
 /**
@@ -1135,7 +1138,7 @@ gtr_tab_get_active_view (GtrTab * tab)
  * gtr_tab_get_all_views:
  * @tab: the #GtranslationTab
  * @original: TRUE if you want original TextViews.
- * @translated: TRUE if you want tranlated TextViews.
+ * @translated: TRUE if you want translated TextViews.
  *
  * Returns all the views currently present in #GtranslationTab
  *
