@@ -61,7 +61,7 @@
 #define GTR_STOCK_FUZZY_UNTRANS_NEXT "gtranslator-fuzzy-untranslated-next"
 #define GTR_STOCK_FUZZY_UNTRANS_PREV "gtranslator-fuzzy-untranslated-prev"
 
-#define PROFILE_DATA "GtrWidnowProfileData"
+#define PROFILE_DATA "GtrWindowProfileData"
 
 typedef struct
 {
@@ -163,7 +163,7 @@ drag_data_received_cb (GtkDropTarget * drop_target,
   return TRUE;
 }
 
-void
+static void
 set_window_title (GtrWindow * window, gboolean with_path)
 {
   GtrPo *po;
@@ -415,6 +415,7 @@ gtr_window_create_tab (GtrWindow * window, GtrPo * po)
   GtrTab *tab;
   AdwNavigationPage *page;
 
+  gtr_window_remove_tab (window);
   tab = gtr_tab_new (po, GTK_WINDOW (window));
   priv->active_tab = tab;
 
@@ -740,7 +741,7 @@ gtr_window_tm_keybind (GtrWindow *window,
   g_list_free_full (tm_list, free_match);
 }
 
-void
+static void
 gtr_window_show_search_bar (GtrWindow *window,
                             gboolean show)
 {
